@@ -1,6 +1,6 @@
 package CSS::Minifier::XS;
 
-use 5.006;
+use 5.8.8;
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 our @EXPORT_OK = qw(minify);
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 bootstrap CSS::Minifier::XS $VERSION;
 
@@ -130,7 +130,7 @@ and be sure to include the CSS that you're having troubles minifying.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007, Graham TerMarsch.  All Rights Reserved.
+Copyright (C) 2007-2010, Graham TerMarsch.  All Rights Reserved.
 
 This is free software; you can redistribute it and/or modify it under the same
 license as Perl itself.
